@@ -23,7 +23,7 @@
  * in the United States and other countries.]
  *
  * ------------
- * $Id: InfiniteMinorAxisLayoutStep.java 3524 2007-10-16 11:26:31Z tmorgner $
+ * $Id: InfiniteMinorAxisLayoutStep.java 6653 2008-12-02 14:53:40Z tmorgner $
  * ------------
  * (C) Copyright 2006-2007, by Pentaho Corporation.
  */
@@ -59,7 +59,7 @@ import org.jfree.layouting.renderer.process.layoutrules.ReplacedContentSequenceE
 import org.jfree.layouting.renderer.process.layoutrules.SpacerSequenceElement;
 import org.jfree.layouting.renderer.process.layoutrules.StartSequenceElement;
 import org.jfree.layouting.renderer.process.layoutrules.TextSequenceElement;
-import org.jfree.util.Log;
+import org.pentaho.reporting.libraries.base.util.DebugLog;
 
 /**
  * This process-step computes the effective layout, but it does not take
@@ -540,7 +540,7 @@ public class InfiniteMinorAxisLayoutStep
       final long minimumChunkWidth = paragraph.getMinimumChunkWidth();
       processor.initialize(sequence,
           lineStart, lineStart + minimumChunkWidth, pageGrid);
-      Log.warn("Auto-Corrected zero-width linebox.");
+      DebugLog.log("Auto-Corrected zero-width linebox.");
     }
     else
     {
